==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_rules.js <==
_me = frm_rules.prototype;
function frm_rules() {};

_me.__constructor = function(aValues) {
	var me = this;

	this._title('FILTERS::RULES');
	this._draw('frm_rules', 'main');
	this._size(450);
	
	storage.library('obj_filter_line');
	this.__aFilterLine = new obj_filter_line;
	
	this.__valuesOfLines = [];
	this.__labelsOfLines = [];
	
	this.__unselectLine();
	
	this.active._onclick = function() {
		if (this._value()) {
			me.x_add._disabled(false);
		} else {
			me.x_add._disabled(true);
			me.__unselectLine();
		}
	}


	this.rules._onclick = function() {
		if (count(this._value()) == 1) {
			me.__selectLine();
		} else {
			me.__unselectLine();
		}
	}

	this.rules._ondblclick = function() {
		var index = parseInt((this._value()[0]));
		if (index != NaN) me.__editLine(index);
	}

    this.rules._oncheck = function(e,key,val){
		 me.__valuesOfLines[key].ACTIVE = [{VALUE:val?'1':'0'}];
	}

	this.x_add._onclick = function() {
		gui._create('edit_rule', 'frm_rule', '', '',{}, [me, '__addLineWithFill']);
	}
	this.x_edit._onclick = function() {
		var index = parseInt((me.rules._value()[0]));
		if (index != NaN) me.__editLine(index);
	}
	this.x_delete._onclick = function() {
		var index = parseInt((me.rules._value()[0]));
		if (index != NaN) me.__deleteLine(index);
	}
	this.x_up._onclick = function() {
		var index = parseInt((me.rules._value()[0]));
		if (index != NaN) me.__moveUpLine(index);
	}
	this.x_down._onclick = function() {
		var index = parseInt((me.rules._value()[0]));
		if (index != NaN) me.__moveDownLine(index);
	}
	
	this.x_btn_ok._onclick = function() {
		var aValues;	
		var aFilters = [];
		delete aXmlFilter['CONTENTFILTER'][0]['FILTER'];

		for (var i in me.__valuesOfLines) {
			aValues = me.__valuesOfLines[i];
			if (!Is.Empty(aValues['CONDITION'])) {
				aFilters.push(aValues);
			} 
		}
		if (!Is.Empty(aFilters)) {
			aXmlFilter['CONTENTFILTER'][0]['FILTER'] = aFilters;
		}
		
		aStorageFilters['VALUES']['u_blackwhitefilter'] = me.active._value() ? '1' : '0';
		
		var sXmlFilter = (XMLTools.Arr2Str(aXmlFilter,true)).replace(/></g, '>\n<');
		aStorageFilters['VALUES']['u_rulescontentxml'] = sXmlFilter;


		GWOthers.set('FILTER_RULES', aStorageFilters['VALUES'], 'storage');
		WMStorage.set({'resources':dataSet.get('storage')},'storage');

		me._destruct();
	}
	
	storage.library('wm_storage');
	storage.library('gw_others');

	dataSet.add('storage','',WMStorage.get({'resources': ['FILTER_RULES']}));

	var aStorageFilters = GWOthers.get('FILTER_RULES', 'storage');

	var sXmlFilter = aStorageFilters['VALUES']['u_rulescontentxml'];
	var aXmlFilter = XMLTools.Str2Arr(sXmlFilter);

	this.active._value((aStorageFilters['VALUES']['u_blackwhitefilter'] == '0') ? false : true);
	this.active._onclick();

	for (var i in aXmlFilter['CONTENTFILTER'][0]['FILTER']){
		var aFilter = aXmlFilter['CONTENTFILTER'][0]['FILTER'][i];
		this.__addLine(aFilter);
	}


	this.__refreshLines();
}

_me.__unselectLine = function() {
	this.rules._value([]);

	this.x_delete._disabled(true);
	this.x_edit._disabled(true);
	this.x_up._disabled(true);
	this.x_down._disabled(true);
}

_me.__selectLine = function(sName) {
	if (this.active._value() == false) return;
	
	this.x_delete._disabled(false);
	this.x_edit._disabled(false);
	this.x_up._disabled(false);
	this.x_down._disabled(false);
}

_me.__addLineWithFill = function(aValues) {
	this.__addLine(aValues);
	this.__refreshLines();
	this.rules._value(this.__valuesOfLines.length-1);
}

_me.__addLine = function(aValues) {

	var sLabel = this.__getLabel(aValues);

	if (sLabel) {
	    var a = {title:sLabel};

		if (aValues.ACTIVE && aValues.ACTIVE[0].VALUE>0)
		    a.checked = '1';

		if (aValues.ACCEPT && aValues.ACCEPT[0].VALUE>0)
		    a.css = 'accept';
		else
		if (aValues.DELETE && aValues.DELETE[0].VALUE>0)
			a.css = 'delete';
		else
		if (aValues.MARKSPAM && aValues.MARKSPAM[0].VALUE>0)
		    a.css = 'spam';
		else
		if (aValues.REJECT && aValues.REJECT[0].VALUE>0)
			a.css = 'reject';

	
		this.__labelsOfLines.push(a);
		this.__valuesOfLines.push(aValues);
	}
}

_me.__deleteLine = function(index) {	
	for (var i = index; i < this.__valuesOfLines.length-1; i++) {
		this.__labelsOfLines[i] = this.__labelsOfLines[i+1];
		this.__valuesOfLines[i] = this.__valuesOfLines[i+1];
	}
	this.__labelsOfLines.pop();
	this.__valuesOfLines.pop();

	this.__refreshLines();
	this.__unselectLine();
}

_me.__editLine = function(index) {
	gui._create('edit_rule', 'frm_rule', '','', this.__valuesOfLines[index], [this, '__editLineCallback']);
}

_me.__editLineCallback = function(aValues) {

	var index;
	if ((index = this.__findLine(aValues)) < 0) return;	

	var sLabel = this.__getLabel(aValues);
	
	if (sLabel) {

	    var a = {title:sLabel};

		if (aValues.ACTIVE && aValues.ACTIVE[0].VALUE>0)
		    a.checked = '1';

		if (aValues.ACCEPT && aValues.ACCEPT[0].VALUE>0)
		    a.css = 'accept';
		else
		if (aValues.DELETE && aValues.DELETE[0].VALUE>0)
			a.css = 'delete';
		else
		if (aValues.MARKSPAM && aValues.MARKSPAM[0].VALUE>0)
		    a.css = 'spam';
		else
		if (aValues.REJECT && aValues.REJECT[0].VALUE>0)
			a.css = 'reject';

		this.__labelsOfLines[index] = a;
		this.__refreshLines();
	}
	else
		this.__deleteLine(index);
}

_me.__getLabel = function(aValues) {
	if (Is.Defined(aValues['TITLE']) && aValues['TITLE'][0]['VALUE']) {
		return aValues['TITLE'][0]['VALUE'];
	} else {
		return this.__aFilterLine._getText(aValues);
	}
}

_me.__moveUpLine = function(index) {
	if (index <= 0) return;
	this.__swapLines(index-1, index);
	this.rules._value([index-1]);
}

_me.__moveDownLine = function(index) {
	if (index >= this.__valuesOfLines.length-1) return;
	this.__swapLines(index, index+1);
	this.rules._value([index+1]);
}

_me.__swapLines = function(i1, i2) {
	var tmpValue = this.__valuesOfLines[i1];
	this.__valuesOfLines[i1] = this.__valuesOfLines[i2];
	this.__valuesOfLines[i2] = tmpValue;
	var tmpLabel = this.__labelsOfLines[i1];
	this.__labelsOfLines[i1] = this.__labelsOfLines[i2];
	this.__labelsOfLines[i2] = tmpLabel;
	
	this.__refreshLines();
}

_me.__findLine = function(aValues) {
	for (var i in this.__valuesOfLines) {
		if (this.__valuesOfLines[i] == aValues)
			return parseInt(i); 	
	}
	return -1;
}

_me.__refreshLines = function(){
	this.rules._fill(this.__labelsOfLines);
}

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_rules.js <==
_me = frm_rules.prototype;
function frm_rules() {};

_me.__constructor = function(aValues) {
	var me = this;

	this._title('FILTERS::RULES');
	this._draw('frm_rules', 'main');
	this._size(450,'',true);
	
	storage.library('obj_filter_line');
	this.__aFilterLine = new obj_filter_line;
	
	this.__valuesOfLines = [];
	this.__labelsOfLines = [];
	
	this.__unselectLine();
	
	this.active._onclick = function() {
		if (this._value()) {
			me.x_add._disabled(false);
		} else {
			me.x_add._disabled(true);
			me.__unselectLine();
		}
	}


	this.rules._onclick = function() {
		if (count(this._value()) == 1) {
			me.__selectLine();
		} else {
			me.__unselectLine();
		}
	}

	this.rules._ondblclick = function() {
		var index = parseInt((this._value()[0]));
		if (index != NaN) me.__editLine(index);
	}

    this.rules._oncheck = function(e,key,val){
		 me.__valuesOfLines[key].ACTIVE = [{VALUE:val?'1':'0'}];
	}

	this.x_add._onclick = function() {
		gui._create('edit_rule', 'frm_rule', '', '',{}, [me, '__addLineWithFill']);
	}
	this.x_edit._onclick = function() {
		var index = parseInt((me.rules._value()[0]));
		if (index != NaN) me.__editLine(index);
	}
	this.x_delete._onclick = function() {
		var index = parseInt((me.rules._value()[0]));
		if (index != NaN) me.__deleteLine(index);
	}
	this.x_up._onclick = function() {
		var index = parseInt((me.rules._value()[0]));
		if (index != NaN) me.__moveUpLine(index);
	}
	this.x_down._onclick = function() {
		var index = parseInt((me.rules._value()[0]));
		if (index != NaN) me.__moveDownLine(index);
	}
	
	this.x_btn_ok._onclick = function() {
		var aValues;	
		var aFilters = [];
		delete aXmlFilter['CONTENTFILTER'][0]['FILTER'];

		for (var i in me.__valuesOfLines) {
			aValues = me.__valuesOfLines[i];
			if (!Is.Empty(aValues['CONDITION'])) {
				aFilters.push(aValues);
			} 
		}
		if (!Is.Empty(aFilters)) {
			aXmlFilter['CONTENTFILTER'][0]['FILTER'] = aFilters;
		}

		aStorageFilters['VALUES']['u_blackwhitefilter'] = me.active._value() ? '1' : '0';
		aStorageFilters['VALUES']['u_rulescontentxml'] = (XMLTools.Arr2Str(aXmlFilter,true)).replace(/></g, '>\n<');

		GWOthers.set('FILTER_RULES', aStorageFilters['VALUES'], 'storage');
		WMStorage.set({'resources':dataSet.get('storage')},'storage');

		me._destruct();
	}
	
	storage.library('wm_storage');
	storage.library('gw_others');

	var aStorageFilters = GWOthers.get('FILTER_RULES', 'storage','',true);

	var sXmlFilter = aStorageFilters['VALUES']['u_rulescontentxml'];
	var aXmlFilter = XMLTools.Str2Arr(sXmlFilter);

	this.active._value((aStorageFilters['VALUES']['u_blackwhitefilter'] == '0') ? false : true);
	this.active._onclick();

	for (var i in aXmlFilter['CONTENTFILTER'][0]['FILTER']){
		var aFilter = aXmlFilter['CONTENTFILTER'][0]['FILTER'][i];
		this.__addLine(aFilter);
	}


	this.__refreshLines();
}

_me.__unselectLine = function() {
	this.rules._value([]);

	this.x_delete._disabled(true);
	this.x_edit._disabled(true);
	this.x_up._disabled(true);
	this.x_down._disabled(true);
}

_me.__selectLine = function(sName) {
	if (this.active._value() == false) return;
	
	this.x_delete._disabled(false);
	this.x_edit._disabled(false);
	this.x_up._disabled(false);
	this.x_down._disabled(false);
}

_me.__addLineWithFill = function(aValues) {
	this.__addLine(aValues);
	this.__refreshLines();
	this.rules._value(this.__valuesOfLines.length-1);
}

_me.__addLine = function(aValues) {

	var sLabel = this.__getLabel(aValues);

	if (sLabel) {
	    var a = {title:sLabel};

		if (aValues.ACTIVE && aValues.ACTIVE[0].VALUE>0)
		    a.checked = '1';

		if (aValues.ACCEPT && aValues.ACCEPT[0].VALUE>0)
		    a.css = 'accept';
		else
		if (aValues.DELETE && aValues.DELETE[0].VALUE>0)
			a.css = 'delete';
		else
		if (aValues.MARKSPAM && aValues.MARKSPAM[0].VALUE>0)
		    a.css = 'spam';
		else
		if (aValues.REJECT && aValues.REJECT[0].VALUE>0)
			a.css = 'reject';

		this.__labelsOfLines.push(a);
		this.__valuesOfLines.push(aValues);
	}
}

_me.__deleteLine = function(index) {	
	for (var i = index; i < this.__valuesOfLines.length-1; i++) {
		this.__labelsOfLines[i] = this.__labelsOfLines[i+1];
		this.__valuesOfLines[i] = this.__valuesOfLines[i+1];
	}
	this.__labelsOfLines.pop();
	this.__valuesOfLines.pop();

	this.__refreshLines();
	this.__unselectLine();
}

_me.__editLine = function(index) {
	gui._create('edit_rule', 'frm_rule', '','', this.__valuesOfLines[index], [this, '__editLineCallback']);
}

_me.__editLineCallback = function(aValues) {

	var index;
	if ((index = this.__findLine(aValues)) < 0) return;	

	var sLabel = this.__getLabel(aValues);
	
	if (sLabel) {

	    var a = {title:sLabel};

		if (aValues.ACTIVE && aValues.ACTIVE[0].VALUE>0)
		    a.checked = '1';

		if (aValues.ACCEPT && aValues.ACCEPT[0].VALUE>0)
		    a.css = 'accept';
		else
		if (aValues.DELETE && aValues.DELETE[0].VALUE>0)
			a.css = 'delete';
		else
		if (aValues.MARKSPAM && aValues.MARKSPAM[0].VALUE>0)
		    a.css = 'spam';
		else
		if (aValues.REJECT && aValues.REJECT[0].VALUE>0)
			a.css = 'reject';

		this.__labelsOfLines[index] = a;
		this.__refreshLines();
	}
	else
		this.__deleteLine(index);
}

_me.__getLabel = function(aValues) {
	if (Is.Defined(aValues['TITLE']) && aValues['TITLE'][0]['VALUE'])
		return aValues['TITLE'][0]['VALUE'];
	else
		return this.__aFilterLine._getText(aValues);
}

_me.__moveUpLine = function(index) {
	if (index <= 0) return;
	this.__swapLines(index-1, index);
	this.rules._value([index-1]);
}

_me.__moveDownLine = function(index) {
	if (index >= this.__valuesOfLines.length-1) return;
	this.__swapLines(index, index+1);
	this.rules._value([index+1]);
}

_me.__swapLines = function(i1, i2) {
	var tmpValue = this.__valuesOfLines[i1];
	this.__valuesOfLines[i1] = this.__valuesOfLines[i2];
	this.__valuesOfLines[i2] = tmpValue;
	var tmpLabel = this.__labelsOfLines[i1];
	this.__labelsOfLines[i1] = this.__labelsOfLines[i2];
	this.__labelsOfLines[i2] = tmpLabel;
	
	this.__refreshLines();
}

_me.__findLine = function(aValues) {
	for (var i in this.__valuesOfLines) {
		if (this.__valuesOfLines[i] == aValues)
			return parseInt(i); 	
	}
	return -1;
}

_me.__refreshLines = function(){
	this.rules._fill(this.__labelsOfLines);
}
